@@ -300,7 +300,16 @@ class ChecksOdooModulePO:
                 print(f"{msg} - [{check_error}]")
 
 
-def run(po_files, enable=None, disable=None, no_verbose=False, no_exit=False):
+def run(po_files, enable=None, disable=None, no_verbose=False, no_exit=False, list_msgs=False):
+    if list_msgs:
+        _, checks_docstring = utils.get_checks_docstring([ChecksOdooModulePO])
+        if not no_verbose:
+            print("Emittable messages with the current interpreter:", end="")
+            print(checks_docstring)
+        if no_exit:
+            return checks_docstring
+        sys.exit(0)
+
     all_check_errors = []
     exit_status = 0
     for po_file in po_files:
